<?php

declare(strict_types=1);

namespace App\Form;

use App\Entity\DrinkType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\GreaterThanOrEqual;
use Symfony\Component\Validator\Constraints\NotBlank;

class DrinkTypeStockEditType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('id', HiddenType::class, [
                'mapped' => false,
            ])
            ->add('name', TextType::class, [
                'disabled' => true,
                'attr' => [
                    'readonly' => true,
                ],
            ])
            ->add('currentStock', NumberType::class, [
                'label' => 'Current Stock',
                'attr' => [
                    'min' => 0,
                    'step' => 1,
                    'class' => 'form-control',
                ],
                'constraints' => [
                    new NotBlank([
                        'message' => 'Current stock cannot be blank',
                    ]),
                    new GreaterThanOrEqual([
                        'value' => 0,
                        'message' => 'Current stock must not be negative',
                    ]),
                ],
            ]);
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => DrinkType::class,
        ]);
    }
}
